@@ -7,10 +7,10 @@ module Rails
   end
 
   module VERSION
-    MAJOR = 7
-    MINOR = 1
-    TINY  = 5
-    PRE   = "2"
+    MAJOR = 8
+    MINOR = 0
+    TINY  = 2
+    PRE   = nil
 
     STRING = [MAJOR, MINOR, TINY, PRE].compact.join(".")
   end
